require 'spec_helper'

module G5RepsClient
  describe SaveLeadRequest do

    let(:lead) do
      {prefix: "Mr.",
       first_name: "G5Test",
       last_name: "Testing",
       suffix: "Jr.",
       address1: "22 Test Drive",
       city: "Bend",
       state: "OR",
       zip_code: "97702",
       phone: "5413334444",
       email: "G5Test@test.com",
       relationship_to_prospect_id: "2",
       source_id: 77}
    end

    describe 'execute' do

      it "calls the SavonAdapter" do
        expect(SavonAdapter).to receive(:call).with(:save_lead,
                                                    message = { enterprise_key: "ShinyAndChrome",
                                                    community_id: "5",
                                                    new_contact: [{"Prefix" => "Mr.",
                                                                   "FirstName" => "G5Test",
                                                                   "LastName" => "Testing",
                                                                   "Suffix" => "Jr.",
                                                                   "Address1" => "22 Test Drive",
                                                                   "City" => "Bend",
                                                                   "State" => "OR",
                                                                   "ZipCode" => "97702",
                                                                   "Phone" => "5413334444",
                                                                   "Email" => "G5Test@test.com",
                                                                   "RelationshipToProspectId" => "2",
                                                                   "SourceId" => "77"}],
                                                    new_prospect: [{}]},
                                                    "http://test.com?wsdl")


        SaveLeadRequest.execute("ShinyAndChrome", "http://test.com?wsdl", "5", lead)
      end
    end

    describe 'camelcase_keys' do
      it "Camel cases keys, wraps the hash in array brackets, and stringifies the hash for reps friendliness" do
        SaveLeadRequest.camelcase_keys(lead).should eq([{"Prefix" => "Mr.",
                                                         "FirstName" => "G5Test",
                                                         "LastName" => "Testing",
                                                         "Suffix" => "Jr.",
                                                         "Address1" => "22 Test Drive",
                                                         "City" => "Bend",
                                                         "State" => "OR",
                                                         "ZipCode" => "97702",
                                                         "Phone" => "5413334444",
                                                         "Email" => "G5Test@test.com",
                                                         "RelationshipToProspectId" => "2",
                                                         "SourceId" => "77"}])
      end
    end

  end
end